# Copyright (c) 2017, University of Bristol and University of Southampton.

from EStat.Templating import Template

class Regression1(Template):
    'A model template for fitting 1 level Normal multiple regression model in eStat only.'

    __version__ = '1.0.0'

    tags = [ 'Model', '1-Level', 'Normal' ]
    engines = ['eStat']

    inputs = '''
y = DataVector('Response: ', help= 'a.k.a. <em>Y</em>, Outcome variable, Dependent variable, etc.')
x = DataMatrix('Explanatory variables: ', allow_cat = True, help= "<p style='text-align:left'>A.k.a. X, Predictor variables, Independent variables, etc.</p><p style='text-align:left'><strong>Note:</strong> if you wish to include an <strong>intercept</strong> then you need to add it (e.g. a constant of ones) as one of the explanatory variables.</p><p style='text-align:left'>Once you've selected a variable, you have the opportunity to indicate whether it's categorical or not; if categorical, dummy variables will be added to the model on your behalf.</p>")
beta = ParamVector(parents=[x], as_scalar=True)
tau = ParamScalar()
sigma = ParamScalar(modelled = False)
sigma2 = ParamScalar(modelled = False)
deviance = ParamScalar(modelled = False)
'''
        
    model = '''
model{
    for (i in 1:length(${y})) {
        ${y}[i] ~ dnorm(mu[i], tau)
        mu[i] <- ${mmult(x, 'beta', 'i')}
    }
    
    # Priors
    % for i in range(0, x.ncols()):
    beta_${i} ~ dflat()
    % endfor
    tau ~ dgamma(0.001000, 0.001000)
    sigma2 <- 1 / tau
    sigma <- 1 / sqrt(tau)
}
'''
    
    latex = r'''
\begin{aligned}
 \mbox{${y}}_i & \sim \mbox{N}(\mu_i, \sigma^2) \\ 
\mu_i & =
  ${mmulttex(x, r'\beta', 'i')} \\ 
%for i in range(0, len(x)):
\beta_${i} & \propto 1 \\ 
%endfor
\tau & \sim \Gamma (0.001,0.001) \\ 
\sigma^2 & = 1 / \tau
\end{aligned} 
'''
